@@ -84,7 +84,7 @@ class Wimby:
                     hold_score = max((buy_score, sell_score))
                     if pattern.strip() != "":
                         print(f"    {pattern}")
-                        if hold_score <= 60
+                        if hold_score <= 60:
                             print(f"    HOLD: {sell_score:,.2f}%")
                         elif buy_score > sell_score:
                             print(f"    BUY:  {buy_score:,.2f}%")
